AttendeeProperty class

RFC2445 Section 4.8.4.1

Inheritance

Constructors

AttendeeProperty(String email, {Locale? locale, CalendarUserType? userType, List<String>? membershipEmails, ParticipationRoleType? participationRoleType, ParticipationStatusType? participationStatusType, bool? rsvpExpectation, List<String>? delegateeEmails, List<String>? delegatorEmails, String? sentByEmail, String? commonName, Uri? directoryEntryUri})
AttendeeProperty.fromCrawledProperty(CrawledProperty property)
factory

Properties

commonName String?
final
delegateeEmails List<String>?
final
delegatorEmails List<String>?
final
directoryEntryUri Uri?
final
hashCode int
The hash code for this object.
no setterinherited
locale → Locale?
final
membershipEmails List<String>?
final
participationRoleType ParticipationRoleType?
final
participationStatusType ParticipationStatusType?
final
propertyName String
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
rsvpExpectation bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentByEmail String?
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
userType CalendarUserType?
final
value CalendarUserAddressValue
finalinherited

Methods

getParameters() List<CalendarParameter<CalendarParameterValue>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited